pub enum ClientError {
Http(Error),
Hyper(Error),
Serialization(Error),
InvalidHeaderValue(InvalidHeaderValue),
Reqwest(Error),
RequestFailed(String),
}Variants
Http(Error)
Hyper(Error)
Serialization(Error)
InvalidHeaderValue(InvalidHeaderValue)
Reqwest(Error)
RequestFailed(String)
Implementations
Sourceimpl ClientError
impl ClientError
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if the error is a timeout error
Sourcepub fn is_connect(&self) -> bool
pub fn is_connect(&self) -> bool
Returns true if the error is a connection error
Sourcepub fn is_request(&self) -> bool
pub fn is_request(&self) -> bool
Returns true if the error occurred during request building